pub struct StructuralBlock {
pub kind: String,
pub ordinal: u64,
pub body: Vec<u8>,
}Expand description
A read-only structural metadata block derived from the backing file
(FLAC STREAMINFO/SEEKTABLE). Stored outside the editable tags contract.
Fields
kind: Stringordinal: u64body: Vec<u8>Trait Implementations
Sourceimpl Clone for StructuralBlock
impl Clone for StructuralBlock
Sourcefn clone(&self) -> StructuralBlock
fn clone(&self) -> StructuralBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuralBlock
impl Debug for StructuralBlock
impl Eq for StructuralBlock
Sourceimpl PartialEq for StructuralBlock
impl PartialEq for StructuralBlock
Sourcefn eq(&self, other: &StructuralBlock) -> bool
fn eq(&self, other: &StructuralBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StructuralBlock